==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebRowDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDirectiveDescription } from "./WebRowDirectiveDescription";
/**
 * @hidden
 */
export let WebRowDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowDirectiveDescriptionMetadata.a == null) {
                WebRowDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowDirectiveDescriptionMetadata.c(WebRowDirectiveDescriptionMetadata.a);
            }
            if (a.j(WebRowDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRowDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Data", "Unknown");
            a.item("Index", "Number:double");
            a.item("Disabled", "Boolean");
            a.item("Pinned", "Boolean");
            a.item("Expanded", "Boolean");
            a.item("Selected", "Boolean");
        }
        static d(a) {
            WebRowDirectiveDescriptionMetadata.b(a);
            a.aa("WebRowDirective", () => new WebRowDirectiveDescription());
            a.z("WebRowDirective", WebRowDirectiveDescriptionMetadata.a);
        }
    }
    WebRowDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowDirectiveDescriptionMetadata, 'WebRowDirectiveDescriptionMetadata');
    WebRowDirectiveDescriptionMetadata.a = null;
    return WebRowDirectiveDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRowDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowDirectiveDescription } from "./WebRowDirectiveDescription";
/**
 * @hidden
 */
export let WebRowDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowDirectiveDescriptionMetadata.a == null) {
                WebRowDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowDirectiveDescriptionMetadata.c(WebRowDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebRowDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRowDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Data", "Unknown");
            a.item("Index", "Number:double");
            a.item("Disabled", "Boolean");
            a.item("Pinned", "Boolean");
            a.item("Expanded", "Boolean");
            a.item("Selected", "Boolean");
        }
        static d(a) {
            WebRowDirectiveDescriptionMetadata.b(a);
            a.ac("WebRowDirective", () => new WebRowDirectiveDescription());
            a.ab("WebRowDirective", WebRowDirectiveDescriptionMetadata.a);
        }
    }
    WebRowDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowDirectiveDescriptionMetadata, 'WebRowDirectiveDescriptionMetadata');
    WebRowDirectiveDescriptionMetadata.a = null;
    return WebRowDirectiveDescriptionMetadata;
})();
